# Analytics

We provide pre-integrations with multiple Analytics vendors. In most cases, you will only need to initialize the plugin with your account credentials and optional custom data. The SDK will take care of sending the required playback events (e.g. playback start/pause/stop, buffering, seeking, ad start/stop...) to the Analytics backend. 

## Youbora

`Youbora Analytics` is a comprehensive analytics and monitoring platform specifically designed for online video streaming services. It provides real-time insights and data analytics to help content providers and broadcasters understand the performance and usage of their video content.

Developed by [Nice People At Work](http://nicepeopleatwork.com/), Youbora Analytics offers a wide range of features and capabilities to track, measure, and optimize video streaming performance. It collects data from various sources, including video players, content delivery networks (CDNs), and end-user devices, and transforms that data into meaningful metrics and reports.

Our integration is validated by Nice People at Work QA.

### Integrate

To start with Youbora Analytics first register a plugin to PRESTOPlay SDK:

```swift
import CastlabsYoubora

...

let youboraSettings = YouboraSettings(accountCode: "...")
let youboraPlugin = CastlabsYoubora(youboraSettings)
PRESTOPlay.shared.register([youboraPlugin])
```

### Custom Metadata

If you want to use custom Youbora client settings you will have to import `YouboraLib` to your project.
The easiest way is to add it via `Podfile`:

```swift
pod 'YouboraLib'
```

To pass custom data:

```swift
var analytics: AnalyticsAPI = PRESTOPlaySDK.shared.analytics(for: player, .youbora)

...

let youboraMetadata = YouboraMetadata(
    live: false,
    assetId: "assetId"
)
youboraMetadata.options = YBOptions()
youboraMetadata.options?.adCustomDimension1 = "test"
youboraMetadata.options?.contentTitle = "test"
analytics?.metadata = youboraMetadata
```

Please check our `examples/` for complete implementation.
