//
//  DemosView.swift
//  Demos
//
//

import PRESTOPlay
import SwiftUI

struct Demo: Identifiable {
    let id = UUID()
    var title: String
    var description: String

    var url: String?
    var contentType: ContentType?
    var playerConfiguration: PlayerConfiguration?
    var drmConfiguration: DrmConfiguration?
    var sideloadedSubtitle: String?
    var sideloadedThumbnail: String?
    var youboraEnabled: Bool?
}

var drmConfiguration: DrmConfiguration {
    get {
        let drm = DrmConfiguration()
        drm.environment = .staging
        drm.merchant = "six"
        drm.assetId = "twelve"
        drm.userId = "rental1"
        drm.sessionId = "p0"
        return drm
    }
}

struct DemosView: View {
    @State var demosList = [
        Demo(
            title: "HLS Playback",
            description: "Basic HLS playback demo",
            url: "https://demo.cf.castlabs.com/media/prestohls/master.m3u8"
        ),
        Demo(
            title: "Fairplay HLS Playback",
            description: "Basic Fairplay protected HLS playback demo",
            url: "https://demo.cf.castlabs.com/media/fps/prog_index.m3u8",
            drmConfiguration: drmConfiguration
        ),
        Demo(
            title: "WebVTT Subtitles",
            description: "Add sideloaded WebVTT thumbnails",
            url: "https://demo.cf.castlabs.com/media/prestohls/master.m3u8",
            sideloadedSubtitle: "https://demo.cf.castlabs.com/media/players/presto.vtt"
        ),
        Demo(
            title: "WebVTT Thumbnails",
            description: "Add sideloaded WebVTT thumbnails",
            url: "https://demo.cf.castlabs.com/media/prestohls/master.m3u8",
            sideloadedThumbnail: "https://demo.castlabs.com/media/TOS/thumbs/thumbs.vtt"
        ),
        Demo(
            title: "Youbora Analytics",
            description: "Test integration with Youbora analytics",
            url: "https://demo.cf.castlabs.com/media/prestohls/master.m3u8",
            youboraEnabled: true
        ),
    ]

    var body: some View {
        NavigationView {
            List(demosList) { demo in
                NavigationLink {
                    PlayerView(demo: demo)
                } label: {
                    VStack {
                        Text(demo.title)
                            .font(.headline)
                            .frame(maxWidth: .infinity, alignment: .leading)
                        Text(demo.description)
                            .font(.caption)
                            .frame(maxWidth: .infinity, alignment: .leading)
                            .multilineTextAlignment(.leading)
                    }
                }
                .padding(2.0)
            }
        }
    }
}

struct DemosView_Previews: PreviewProvider {
    static var previews: some View {
        DemosView()
    }
}
