//
//  ViewController.swift
//  SubtitlesDemo
//
//

import PRESTOPlay
import CastlabsApple
import CastlabsSubtitles
import AVFoundation
import UIKit

class ViewController: UIViewController {
    // create player instance
    var player = PRESTOPlaySDK.shared.player()
    var subtitles: SubtitlesAPI?

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view.
        // optional: ignore silent switch
        try? AVAudioSession.sharedInstance().setCategory(.playback)

        guard let contentURL =
            URL(
                string: "https://demo.cf.castlabs.com/media/prestohls/master.m3u8")
        else { return }

        let config = PlayerConfiguration(with: contentURL)
        player.load(config: config)

        player.onState = { previous, state in
            if let error = state.playerError {
                print("Error \(error)")
                return
            }

            if state.playbackState == .ready {
                self.addSubtitles()
            }
        }

        player.attach(to: view.layer)
        player.open(autoplay: true)
    }

    override func viewWillTransition(to size: CGSize,
                                     with coordinator: UIViewControllerTransitionCoordinator) {
        player.update(size: size)
    }

    func addSubtitles() {
        subtitles = PRESTOPlaySDK.shared.subtitles(for: player)

        guard let url = URL(string: "https://demo.cf.castlabs.com/media/players/presto.vtt") else {
            print("unable to parse subtitles url")
            return
        }

        let subtitlesTrack = TextTrack(
            id: UUID().uuidString,
            format: .web_vtt,
            isPlatformRendered: false,
            label: "sideloaded",
            language: "en",
            sourceUrl: url)

        subtitles?.addTextTrack(subtitlesTrack, completionHandler: { error in
            if let error { print(error) } else { print("subtitles track loaded") }
            DispatchQueue.main.async {
                self.player.setTextTrack(subtitlesTrack)
            }
        })
    }
}
